////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv;

import javax.swing.*;
import java.awt.event.*;
import java.io.*;
import edu.uiuc.jdbv.util.SuffixFileFilter;


/**
 * An abstract action for load-diagram related actions
 *
 * @version $Revision: 1.3 $
 * @author Uday Kale
 */
public abstract class AbstractLoadAction extends AbstractAction 
{
    /** Description for dbv files */
    public static final String DIAGRAM_FILE_DESC = "JDBV files to load from";

    /** The filename extension for Diagrams = "dbv" */
    public static final String[] DIAGRAM_EXTENSIONS = {"dbv"};

    protected static JFileChooser fileChooser;

    /** The JDBV application instance that created this action */
    protected JDBV jdbv;

    static {
	SuffixFileFilter fileFilter =
		new SuffixFileFilter( DIAGRAM_FILE_DESC, DIAGRAM_EXTENSIONS );
	fileChooser = new JFileChooser( "." );
	fileChooser.addChoosableFileFilter( fileFilter );
    }


    public AbstractLoadAction( String name, JDBV jdbv )
    {
        super( name );
        this.jdbv = jdbv;
    }

    
    /** 
     * Shows a load-diagram dialog box
     * @return the filename the user selected or null if the user cancelled
     */
    protected String showLoadDialog()
    {
	int retval = fileChooser.showOpenDialog(null);
	if (retval == JFileChooser.APPROVE_OPTION) {
	    String filename = fileChooser.getSelectedFile().getPath();
	    System.out.println("filename " + filename+ " chosen");
	    return filename;
	}
        return null;

    }
}

