////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;


/**
 * Defines the action for exiting the application
 *
 * @author Brian Sidharta
 * @version $Revision: 1.6 $
 */
class ExitAction extends AbstractAction
{
    /** The short descriptive text of this action = "Exit" */
    public static final String NAME_VALUE = "Exit";

    /** The mnemonic keycode = KeyEvent.VK_X */
    public static final int MNEMONIC_CODE = KeyEvent.VK_X;

    /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE = 
        "Exits the JDBV application.";

    /** The keystroke key-code = java.awt.event.KeyEevnt.VK_F4 */
    public static final int KEY_STROKE_CODE = KeyEvent.VK_F4;

    /** The keystroke modifier mask = Event.ALT_MASK */
    public static final int KEY_STROKE_MODIFIERS = Event.ALT_MASK;

    /** The icon for the toolbar */
    public static final Icon SMALL_ICON_VALUE = 
        new ImageIcon( ClassLoader.getSystemResource
		       ( "resources/icons/blank16.gif" ));

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = "Exit dbViZ";


    /** The JDBV application instance that created this ExitAction */
    private JDBV jdbv;



    /** Constructor that takes the JDBV application instance */
    public ExitAction( JDBV jdbv )
    {
        super( NAME_VALUE );

        // Setup the action parameters
        KeyStroke keyStroke = 
            KeyStroke.getKeyStroke( KEY_STROKE_CODE, KEY_STROKE_MODIFIERS );
        putValue( ACCELERATOR_KEY, keyStroke );
        putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( SMALL_ICON, SMALL_ICON_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );

        this.jdbv = jdbv;
        
    }

    /** Handles the initiation of this action */
    public void actionPerformed( ActionEvent e )
    {
        // Close all diagrams
        while (jdbv.CLOSE_DIAGRAM_ACTION.isEnabled()) {
            boolean success = jdbv.CLOSE_DIAGRAM_ACTION.initiate();
            if (!success) {
                return; // Couldn't close diagram; abort exit operation
            } // end of if ()
        } // end of while ()
        
        System.exit( 0 );
    }

}

