////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv;

import javax.swing.*;
import java.awt.event.*;

import edu.uiuc.jdbv.schema.*;
import edu.uiuc.jdbv.diagram.Diagram;
import edu.uiuc.jdbv.imports.ImportException;



/**
 * Defines the action for exiting the application
 *
 * @author Brian Sidharta
 * @version $Revision: 1.7 $
 */
class ImportSchemaAction extends AbstractAction
{
    /** The short descriptive text of this action = "Import Schema..." */
    public static final String NAME_VALUE = "Import Schema...";

    /** The mnemonic keycode = KeyEvent.VK_I */
    public static final int MNEMONIC_CODE = KeyEvent.VK_I;

    /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE = 
        "Imports a schema into the application.";

    /** Status message for when schema import is aborted */
    public static final String IMPORT_ABORTED_STATUS =
        "Schema import aborted.";

    /** Status message for when schema import succeeds */
    public static final String IMPORT_SUCCESSFUL_STATUS =
        "Schema imported successfully.";

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = "Import Schema";

    /** The icon for the toolbar */
    public static final Icon SMALL_ICON_VALUE = 
        new ImageIcon( ClassLoader.getSystemResource
		       ( "resources/icons/new16.gif" ));



    /** The JDBV application instance that created this ImportSchemaAction */
    private JDBV jdbv;



    /** Constructor that takes the JDBV application instance */
    public ImportSchemaAction( JDBV jdbv )
    {
        super( NAME_VALUE );

        // Setup the action parameters
        putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( SMALL_ICON, SMALL_ICON_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );

        this.jdbv = jdbv;
        
    }

    /** Handles the initiation of this action */
    public void actionPerformed( ActionEvent e )
    {
        // Show the Import Registry window
        try{
            Schema schema = jdbv.IMPORT_WINDOW.importSchema();
            if( schema == null ) {
                jdbv.MAIN_WINDOW.getStatusBar().
                    setStatus( IMPORT_ABORTED_STATUS );
            } else {
                Diagram diagram = new Diagram( schema );
                jdbv.MAIN_WINDOW.addDiagram( diagram );
                jdbv.updateComponents();
                jdbv.setStatus( IMPORT_SUCCESSFUL_STATUS );
            }

        } catch(ImportException ie) {
            jdbv.setStatus("Import Failed!!!");
            JOptionPane.showMessageDialog
                ( jdbv.MAIN_WINDOW, ie.getMessage(), "Import Failed!",
                  JOptionPane.ERROR_MESSAGE ); 
        }
        
    
    }

}

