////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.XMLDecoder;
import java.io.*;

import edu.uiuc.jdbv.gui.DiagramPane;
import edu.uiuc.jdbv.diagram.Diagram;

/**
 * Defines the action for saving a loaded diagram
 *
 * @author Uday Kale
 * @version $Revision: 1.12 $
 */
class LoadDiagramAction extends AbstractLoadAction {
    /** The short descriptive text of this action = "Open" */
    public static final String NAME_VALUE = "Open...";

    /** The mnemonic keycode = KeyEvent.VK_I */
    public static final int MNEMONIC_CODE = KeyEvent.VK_O;

    /** The keystroke key-code = java.awt.event.KeyEevnt.VK_Z */
    public static final int KEY_STROKE_CODE = KeyEvent.VK_O;

    /** The keystroke modifier mask = Event.CTRL_MASK */
    public static final int KEY_STROKE_MODIFIERS = Event.CTRL_MASK;

    /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE =
        "Loads a saved diagram from a file.";

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = "Open";

    /** The icon for the toolbar */
    public static final Icon SMALL_ICON_VALUE = 
        new ImageIcon( ClassLoader.getSystemResource
		       ( "resources/icons/open16.gif" ));

    /** The JDBV application instance that created this ImportSchemaAction */
    private JDBV jdbv;

    /** Constructor that takes the JDBV application instance */
    public LoadDiagramAction( JDBV jdbv )
    {
        super( NAME_VALUE, jdbv );

        // Setup the action parameters
        KeyStroke keyStroke = 
            KeyStroke.getKeyStroke( KEY_STROKE_CODE, KEY_STROKE_MODIFIERS );
        putValue( ACCELERATOR_KEY, keyStroke );
        putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( SMALL_ICON, SMALL_ICON_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );

        this.jdbv = jdbv;

    }

    /** Handles the initiation of this action */
    public void actionPerformed( ActionEvent e )
    {

	String filename = showLoadDialog();

	if (filename == null)
	    return;

	// Check if the diagram is already open
	DiagramPane dpane = jdbv.MAIN_WINDOW.getDiagramPane();
	for (int i = dpane.getDiagramCount() - 1; i >= 0; --i) {
	    Diagram dgm = dpane.getDiagramAt( i );
	    if (filename.equals( dgm.getFilename())) {
		// File already opened, just make it current and return
		dpane.setSelectedIndex(i);
		//dpane.fireStateChanged();
		return;
		}
	    }

	try {
	    FileInputStream fstream = new FileInputStream(filename);
	    XMLDecoder dec = new XMLDecoder(fstream);

	    try {
		Object obj = dec.readObject();
		if (obj instanceof Diagram) {
                    Diagram diagram = (Diagram)obj;
                    diagram.setModified( false );
		    jdbv.MAIN_WINDOW.addDiagram( diagram );
		}
		else
		    System.out.println("Other object => " + obj);
	    } finally {
		// Close the object stream
		dec.close();
	    }
	} catch(Exception ex) {
	    ex.printStackTrace();
	} // end of try-catch

    }
}
