////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv;

import javax.swing.*;
import java.awt.*;
import java.awt.print.*;
import java.awt.event.*;
import org.apache.log4j.*;
import edu.uiuc.jdbv.util.*;
import edu.uiuc.jdbv.diagram.Diagram;

/**
 * Brings up a print preview frame
 *
 * @author Ross Paul
 * @version $Revision: 1.7 $
 */

class PrintPreviewAction extends AbstractAction
{
    /** The logger to be used for the file = jdbv.PrintPreviewAction */
    private static final Logger logger = 
        Logger.getLogger("jdbv.PrintPreveiwAction");

    /** The short descriptive name = "Print Preview  ..." */
    public static final String NAME_VALUE = "Print Preview ...";
    
    /** The mnemonic keycode = KeyEvent.VK_W */
    public static final int MNEMONIC_CODE = KeyEvent.VK_W;

   /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE = 
        "View the Print Preview";

    /** The icon for the toolbar */
    public static final Icon SMALL_ICON_VALUE = 
        new ImageIcon( ClassLoader.getSystemResource
		       ( "resources/icons/printPreview16.gif" ));

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = "Print Preview";


    /** Handle to the singleton JDBV */
    private JDBV jdbv;

    /** 
     * Constructor takes an instance of JDBV.  Action is disabled whenever a 
     * diagram is not visible.
     */
    public PrintPreviewAction( JDBV jdbv )
    {
        super( NAME_VALUE );
        
        // Setup action parameters
        putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( SMALL_ICON, SMALL_ICON_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );

	this.jdbv = jdbv;
	setEnabled( false );
    }

    public void actionPerformed( ActionEvent e )
    {
        Diagram diagram = jdbv.getCurrentDiagram();
        boolean gridVisible = diagram.isGridVisible();
        diagram.setGridVisible( false );

        new PrintPreview( new PrintUtilities( diagram ),
                          "Print Preview: " + diagram.getName(), 
                          PrintAction.pageFormat);

        diagram.setGridVisible( gridVisible );
    }
}
