////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package  edu.uiuc.jdbv;

import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.undo.*;
import edu.uiuc.jdbv.diagram.Diagram;

/**
 * Defines the undo action which links to the undoManager in the JDBV class
 *
 * @author Ross Paul
 * @version $Revision: 1.8 $
 */
class UndoAction extends AbstractAction 
    implements ChangeListener, UndoableEditListener
{
    /** The short descriptive name defaults to undo, undoManager can provide
     *  more descriptive text */
    public static final String NAME_VALUE = "Undo";
    
    /** The mnemonic keycode = KeyEvent.VK_X */
    public static final int MNEMONIC_CODE = KeyEvent.VK_U;

   /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE = "Undo";

    /** The keystroke key-code = java.awt.event.KeyEevnt.VK_Z */
    public static final int KEY_STROKE_CODE = KeyEvent.VK_Z;

    /** The keystroke modifier mask = Event.CTRL_MASK */
    public static final int KEY_STROKE_MODIFIERS = Event.CTRL_MASK;

    /** The icon for the toolbar */
    public static final Icon SMALL_ICON_VALUE = 
        new ImageIcon( ClassLoader.getSystemResource
		       ( "resources/icons/undo16.gif" ));

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = "Undo";

    /** Handle to the singleton JDBV */
    private JDBV jdbv;

    /** the current UndoManager */
    private UndoManager undoManager;


    /** Constructor takes in an instance of JDBV.  Becomes a Listener to 
     *  DiagramPane upon DiagramPane's instantiation. */
    public UndoAction( JDBV jdbv )
    {
	super( NAME_VALUE );

        // Setup the action parameters
        KeyStroke keyStroke = 
            KeyStroke.getKeyStroke( KEY_STROKE_CODE, KEY_STROKE_MODIFIERS );
        putValue( ACCELERATOR_KEY, keyStroke );
        putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( SMALL_ICON, SMALL_ICON_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );

	this.jdbv = jdbv;
	setEnabled( false );
    }

    /** Sets the appropriate undo state and name in the menu*/
    public void updateState()
    {
	setEnabled( undoManager.canUndo() );
	putValue( NAME, undoManager.getUndoPresentationName() );
    }

    /** 
     * Processes the undoManagers curent redo and updates the states of
     * both undo and redo
     */ 
    public void actionPerformed( ActionEvent e )
    {
	undoManager.undo();
	updateState();
	jdbv.REDO_ACTION.updateState();

    }

    /** Switches undoManagers when the diagram is changed */
    public void stateChanged(ChangeEvent e){
	Diagram diagram = jdbv.getCurrentDiagram();
	if( diagram != null ){
	    undoManager = diagram.getUndoManager();
	    updateState();
	}
	//if there is no undoManager disable edits
	else{
	    setEnabled( false );
	    putValue( NAME, NAME_VALUE);
	}	    
    }

     /** whenever an undoableEdit occurs, update the state */
    public void undoableEditHappened(UndoableEditEvent e)
    {
	updateState();
    }
}
