////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv;

import edu.uiuc.jdbv.diagram.Diagram;
import edu.uiuc.jdbv.gui.StatusBar;
import java.awt.*;
import javax.swing.*;
import java.awt.event.*;
import javax.swing.event.*;


/**
 * Defines the action for zooming into the diagram
 *
 * @author Brian Schoudel
 * @version $Revision: 1.7 $
 */
class ZoomInAction extends AbstractAction implements ChangeListener
{
    /** The short descriptive text of this action = "Zoom In" */
    public static final String NAME_VALUE = "Zoom In";

    /** The mnemonic keycode = KeyEvent.VK_X */
    public static final int MNEMONIC_CODE = KeyEvent.VK_I;

    /** The long description text of this action */
    public static final String LONG_DESCRIPTION_VALUE = 
        "Enlarges the view of the diagram.";

    /** The keystroke key-code = java.awt.event.KeyEevnt.VK_Y */
    public static final int KEY_STROKE_CODE = KeyEvent.VK_EQUALS;

    /** The keystroke modifier mask = Event.CTRL_MASK */
    public static final int KEY_STROKE_MODIFIERS = Event.CTRL_MASK;

    /** The icon for the toolbar */
    public static final Icon SMALL_ICON_VALUE = 
        new ImageIcon( ClassLoader.getSystemResource
		       ( "resources/icons/zoomIn16.gif" ));

    /** Short description for tool-tip */
    public static final String SHORT_DESCRIPTION_VALUE = "Zoom In";

    /** The Zoom-in factor */
    public static final float ZOOM_FACTOR = 1.5f;


    /** The JDBV application instance that created this ZoomInAction */
    private JDBV jdbv;

    private Diagram diagram = null;


    /** Constructor that takes the JDBV application instance */
    public ZoomInAction( JDBV jdbv )
    {
        super( NAME_VALUE );

        // Setup the action parameters
	KeyStroke keyStroke = 
            KeyStroke.getKeyStroke( KEY_STROKE_CODE, KEY_STROKE_MODIFIERS );
        putValue( ACCELERATOR_KEY, keyStroke );
        putValue( MNEMONIC_KEY, new Integer( MNEMONIC_CODE ));
        putValue( LONG_DESCRIPTION, LONG_DESCRIPTION_VALUE );
        putValue( SMALL_ICON, SMALL_ICON_VALUE );
        putValue( SHORT_DESCRIPTION, SHORT_DESCRIPTION_VALUE );

        this.jdbv = jdbv;
        updateState();
        
    }

    /** Handles the initiation of this action */
    public void actionPerformed( ActionEvent e )
    {
	StatusBar statbar = jdbv.getInstance().MAIN_WINDOW.getStatusBar();
        diagram = jdbv.getCurrentDiagram();
        if( diagram != null ) {
            // zoom in
            double currentScale = diagram.getScale();
            diagram.setScale( ZOOM_FACTOR * currentScale );
            statbar.setZoom( ZOOM_FACTOR * currentScale );
	}	
    }


    /** ChangeListener: updates enabled state */
    public void updateState()
    {
        diagram = jdbv.getCurrentDiagram();
	setEnabled( diagram != null );
    }


    /** for ChangeListener */
    public void stateChanged(ChangeEvent e) {
        updateState();
    }

}

