////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.diagram;

import edu.uiuc.jdbv.schema.Connection;
import edu.uiuc.jdbv.schema.Column;

import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.Rectangle;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Map;

import javax.swing.SwingUtilities;
import javax.swing.undo.UndoableEdit;

import com.jgraph.JGraph;
import com.jgraph.graph.*;

/**
 * An EdgeView that shows a Connection between tables
 *
 * @version $Revision: 1.3 $
 * @author Brian Sidharta
 */

public class ConnectionEdgeView extends EdgeView 
{

            

    /** List of points of the edge. May contain ports. */
    //     protected java.util.List points; FROM PARENT

    /** Cached source and target portview of the edge. */
    //     protected PortView source, target; FROM PARENT

    /** Cached label position of the edge. */
    //     protected Point labelPosition; FROM PARENT

    /** Whether all columns are visible */
    protected boolean allColsVisible = false;


    /** Static initialization block */
    static 
    {
        renderer = new ConnectionEdgeRenderer();
    }



    /**
     * Constructs an edge view for the specified model object.
     *
     * @param cell reference to the model object
     */
    public ConnectionEdgeView( Object cell, JGraph graph, CellMapper mapper ) 
    {
        super(cell, graph, mapper);
        update();
    }



    /**
     * Returns the cached points for this edge.
     */
    public Point getPoint(int index) 
    {
        if (index == 0) {
            Connection conn = ((ConnectionEdge)cell).getConnection();
            Column[] depCols = conn.getDependantColumns();
            TableView tableView = getDependentTableView();
            Rectangle tableBounds;
            int xOffset;
            int yOffset;
            Point startPoint = simpleGetPoint( 0 );
            Point nextPoint = simpleGetPoint( 1 );

            // Happens if this isn't initialied with source and target
            if (tableView == null) {
                return( startPoint );
            }

            tableBounds = tableView.getBounds();
            yOffset = tableView.getYOffsetForColumns( depCols ) + 
                tableBounds.y;

            // Calculate allColsVisible value
            allColsVisible = true;
            for (int i = depCols.length - 1; i >= 0; --i) {
                int colOffset = tableView.getYOffsetForColumn( depCols[i]);
                if (colOffset == TableView.COLUMN_HIDDEN_OFFSET) {
                    allColsVisible = false;
                } // end of if ()
            } // end of for ()
            

            if (nextPoint.x < startPoint.x) {
                xOffset = tableBounds.x - 
                    ConnectionEdgeRenderer.MERGEPOINT_DISTANCE;
            } else {
                xOffset = tableBounds.x + tableBounds.width +
                    ConnectionEdgeRenderer.MERGEPOINT_DISTANCE;
            }
     
            

            Point returnPoint = new Point( xOffset, yOffset );

            return (returnPoint);
        } else {
            return (super.getPoint( index ));
        } // end of else
    }


    /**
     * Lightweight version of getPoint that isn't recursive but doesn't
     * return points that should be drawn
     */
    private Point simpleGetPoint( int index )
    {
        Object obj = points.get(index);
        if (obj instanceof Point)
            return (Point) obj;
        else if (obj instanceof PortView) {
            VertexView vertex = (VertexView) ((CellView) obj).getParentView();
            return vertex.getCenterPoint();
        }
        return null;
        
    }
    

    /**
     * Gets the connection's dependent table view
     */
    TableView getDependentTableView()
    {
        Object p0 = points.get( 0 );
        if (p0 instanceof PortView) {
            PortView portView = (PortView)p0;
            TableView tableView = (TableView)portView.getParentView();
            return (tableView);
        } else { // Instanceof Point
            return null;
        } // end of else
        
        
    }
       
 
    /**
     * Retrieves whether all the dependent columns for this connection
     * are visible.
     */
    boolean areAllColsVisible()
    {
        return (allColsVisible);
    }


}
