////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.diagram.xmlPersist;

import edu.uiuc.jdbv.diagram.*;
import java.beans.*;

/**
 * Persistence Delegate that handles Diagrams.
 * @author Brian Sidharta
 * @version $Revision: 1.5 $
 */
public class DiagramPersistenceDelegate extends PersistenceDelegate
{

    protected Expression instantiate( Object oldInstance, Encoder out )
    {
        Diagram diagram = (Diagram)oldInstance;

        Object[] constructorArgs = new Object[] { diagram.getSchema() };
        return (new Expression( diagram, Diagram.class,
                                "new", constructorArgs ));
    }


    protected void initialize(Class type, Object oldInstance, 
                              Object newInstance, Encoder out) 
    {
        super.initialize(type, oldInstance, newInstance, out);

        if (oldInstance.getClass() != Diagram.class) { 
            throw new IllegalArgumentException( "Expected a Diagram as " +
                                                "oldInstance!" );
        }

        Object[] args;
        Diagram diagram = (Diagram)oldInstance;

        // Save Diagram properties
        args = new Object[] {diagram.getFilename()};
        out.writeStatement(new Statement(oldInstance, "setFilename",
                                         args ));

        // Get the bulk of the diagram data. This must remain the last step
        // because setGraphData clears the undo stack as a side effect.
        args = new Object[] {diagram.getGraphData()};
        out.writeStatement(new Statement(oldInstance, "setGraphData", args ));

        args = new Object[] {Boolean.valueOf( diagram.getAutoArrangeMode())};
        out.writeStatement(new Statement(oldInstance, "setAutoArrangeMode",
                                         args ));
    }
    
}

