////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.diagram.xmlPersist;

import java.beans.*;
import java.io.*;

import com.jgraph.JGraph;
import edu.uiuc.jdbv.schema.*;
import edu.uiuc.jdbv.diagram.Diagram;
import edu.uiuc.jdbv.diagram.TableGraphCell;
import edu.uiuc.jdbv.diagram.ConnectionEdge;


/**
 * An XML Encoder that has been initialized to encode Diagrams
 *
 * @author Brian Sidharta
 * @version $Revision: 1.2 $
 */
public class JDBVXMLEncoder extends XMLEncoder
{
    public JDBVXMLEncoder( OutputStream out )
    {
        super( out );
        setupPersistenceDelegates();
    }


    protected void setupPersistenceDelegates()
    {
        // Schema classes
        setPersistenceDelegate( Schema.class, new SchemaPersistenceDelegate());
        setPersistenceDelegate( Table.class, new TablePersistenceDelegate());
        setPersistenceDelegate( Column.class, new ColumnPersistenceDelegate());
        setPersistenceDelegate( Connection.class, 
                                new ConnectionPersistenceDelegate());

        // Diagram classes
        setPersistenceDelegate( JGraph.class, 
                                new JGraphPersistenceDelegate());
        setPersistenceDelegate( Diagram.class, 
                                new DiagramPersistenceDelegate());
        setPersistenceDelegate( TableGraphCell.class, new TableCellPersistenceDelegate());
        setPersistenceDelegate( ConnectionEdge.class, 
                                new ConnectionEdgePersistenceDelegate());
    }
}

