////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.diagram.xmlPersist;

import com.jgraph.JGraph;
import java.beans.*;

/**
 * Persistence Delegate that handles JGraphs
 * @author Brian Sidharta
 * @version $Revision: 1.3 $
 */
public class JGraphPersistenceDelegate extends PersistenceDelegate
{

    protected Expression instantiate( Object oldInstance, Encoder out )
    {
        Object[] constructorArgs = new Object[] {};
        return (new Expression( oldInstance, JGraph.class,
                                "new", constructorArgs ));
    }


    protected void initialize(Class type, Object oldInstance, 
                              Object newInstance, Encoder out) 
    {
        super.initialize(type, oldInstance, newInstance, out);

        if (!(oldInstance instanceof JGraph)) { 
            throw new IllegalArgumentException( "Expected a JGraph as " +
                                                "oldInstance!" );
        }

        Object[] args;
        JGraph jGraph = (JGraph)oldInstance;

        // Handle simple JGraph properties that could be modified in the future

        args = new Object[] {jGraph.getName()};
        out.writeStatement(new Statement(oldInstance, "setName", args));

        args = new Object[] {Boolean.valueOf( jGraph.isAntiAliased())};
        out.writeStatement(new Statement(oldInstance, "setAntiAliased", args));
        
        args = new Object[] {Boolean.valueOf( jGraph.isGridEnabled())};
        out.writeStatement(new Statement(oldInstance, "setGridEnabled",args));

        args = new Object[] {Boolean.valueOf( jGraph.isGridVisible())};
        out.writeStatement(new Statement(oldInstance, "setGridVisible", args));

        args = new Object[] {Boolean.valueOf( jGraph.isMoveable())};
        out.writeStatement(new Statement(oldInstance, "setMoveable", args ));

        args = new Object[] {Boolean.valueOf( jGraph.isSizeable())};
        out.writeStatement(new Statement(oldInstance, "setSizeable", args ));

    }


    
}

