////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.gui;

import java.awt.Component;
import java.awt.Rectangle;
import javax.swing.JList;
import javax.swing.JCheckBox;


import edu.uiuc.jdbv.schema.Connection;
import edu.uiuc.jdbv.schema.Table;

import net.javaprog.ui.DefaultCheckBoxListCellRenderer;

/**
 * The ConnectionListRenderer returns rendering components to paint the cells
 * of the ConnectionList.
 *
 * @author Brian Sidharta
 * @version $Revision: 1.2 $
 */
public class ConnectionListRenderer extends DefaultCheckBoxListCellRenderer
{
    public static final String TO_ARROW = String.valueOf( (char)0xBB );

    public static final String FROM_ARROW = String.valueOf( (char)0xAB );


    private ConnectionListModel model;

    /** constructor that takes the model */
    public ConnectionListRenderer( ConnectionListModel model )
    {
        this.model = model;
    }


    /**
     * Return a component that has been configured to display the 
     * specified value
     */
    public Component getListCellRendererComponent( JList list, 
                                                   Object value,
                                                   int index, 
                                                   boolean isSelected,
                                                   boolean cellHasFocus )
    {
        Component comp = super.getListCellRendererComponent( list, value, 
                                                             index, isSelected, 
                                                             cellHasFocus );
        
        if( (comp instanceof JCheckBox) && 
            ( value instanceof Connection ))
        {
            JCheckBox checkBox = (JCheckBox)comp;
            Connection connection = (Connection)value;
            Table displayTable = connection.getIndependantTable();
            String arrowString = FROM_ARROW;
            if( displayTable.equals( model.getTable())) {
                displayTable = connection.getDependantTable();
                arrowString = TO_ARROW;
            }
            checkBox.setText( arrowString + displayTable.getName());
        }

        return (comp);
    }



    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void validate() 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void revalidate() 
    {
    }
    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void repaint(long tm, int x, int y, int width, int height) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void repaint(Rectangle r) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    protected void firePropertyChange(String propertyName, Object oldValue, 
                                      Object newValue) 
    {
        // Strings get interned...
        if (propertyName=="text")
            super.firePropertyChange(propertyName, oldValue, newValue);
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, byte oldValue,
                                   byte newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, char oldValue,
                                   char newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, short oldValue,
                                   short newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, int oldValue, 
                                   int newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, long oldValue, 
                                   long newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, float oldValue,
                                   float newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, double oldValue, 
                                   double newValue) 
    {
    }

    /**
     * Overridden for performance reasons.
     * See the <a href="#override">Implementation Note</a>
     * for more information.
     */
    public void firePropertyChange(String propertyName, boolean oldValue,
                                   boolean newValue) 
    {
    }



}

