////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.gui;

import com.jgraph.event.*;

import edu.uiuc.jdbv.schema.*;
import edu.uiuc.jdbv.diagram.Diagram;
import edu.uiuc.jdbv.diagram.TableGraphCell;

import java.util.*;
import javax.swing.event.*;


/**
 * Event handler that captures diagram selection events and updates the
 * selected items on the TableList and TableInfoPanel.
 *  
 * @author Brian Sidharta
 * @version $Revision: 1.2 $
 */
public class DiagramSelectionListener implements GraphSelectionListener,
                                                 ListSelectionListener
{

    /** The table list of the window */
    private TableList tableList;

    /** The Tabl info panel of the window */
    private TableInfoPanel tableInfoPanel;

    /** Set used for hashing tables.  */
    private Set tableSet = new HashSet( 31 );

    /** List used for selecting graph cells. */
    private List cellList = new ArrayList( 20 );

    /**
     * Flag on whether the listener is doing selection stuff, which prevents
     * the counterpart valueChanged method from starting an infinite loop
     */
    private boolean selectionInProgress = false;


    /**
     *  Constructor that takes the JDBV Window that it listens on
     *  
     * @param window the JDBVWindow
     */
    public DiagramSelectionListener( JDBVWindow window )
    {
        tableList = window.getTableList();
        tableInfoPanel = window.getTableInfoPanel();

    }


    /** Handles when the Diagram selection is changed */
    public void valueChanged( GraphSelectionEvent e )
    {
        if( selectionInProgress ) {
            return;
        }
        selectionInProgress = true;

        Diagram diagram = (Diagram)e.getSource();
        Object[] cells = diagram.getSelectionCells();
        tableSet.clear();
        for( int i = cells.length - 1; i >= 0; --i ) {
            Object cell = cells[i];
            if( cell instanceof TableGraphCell)
            {
                TableGraphCell tableCell = (TableGraphCell)cell;
                tableSet.add( tableCell.getTable());
            }
        }

        // Select the tables in the TableList
        int[] indexes = new int[cells.length];
        int numSelected = 0; // Number of tables to be selected
        Table[] tables = tableList.getSchema().getTables();
        for( int i = 0; i < tables.length; i++ )
        {
            if( tableSet.contains( tables[i] )) {
                indexes[numSelected++] = i;
            }
        }
        int[] trimmedIndexes = new int[numSelected];
        System.arraycopy( indexes, 0, trimmedIndexes, 0, numSelected );
        tableList.setSelectedIndices( trimmedIndexes );

        selectionInProgress = false;
    }


    /**
     * Handles when the TableList selection is changed */
    public void valueChanged( ListSelectionEvent e )
    {
        if( selectionInProgress ) {
            return;
        }
        selectionInProgress = true;


        Table[] tables = tableList.getSchema().getTables();
        int[] indexes = tableList.getSelectedIndices();
        Diagram diagram = tableList.getDiagram();
        cellList.clear();
        for( int i = 0; i < indexes.length; i++ )
        {
            Table table = tables[indexes[i]];
            System.out.println( "Selected: " + table.getName()); //DEBUG
            Object cell = diagram.getCellForTable( table );
            if( cell != null ) {
                cellList.add( cell );
            }
        }
        Object[] cells = cellList.toArray();
        diagram.setSelectionCells( cells );

        selectionInProgress = false;
    }
}

