////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.gui;

import edu.uiuc.jdbv.JDBV;
import edu.uiuc.jdbv.imports.*;
import edu.uiuc.jdbv.schema.Schema;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

import java.util.*;


/**
 * The window that shows all availale importers and allows them to be invoked
 *
 * @author Abhay Sathe
 * @author Ross Paul
 * @version $Revision: 1.10 $
 */
public class ImportRegistryWindow extends JDialog implements ActionListener
{
    /** The default window size */
    public static final Dimension DEFAULT_WINDOW_SIZE =
        new Dimension( 320, 240 );

    /** The JDBV application this window belongs to */
    private JDBV jdbv;

    /** THe Import Registry */
    private ImportRegistry registry;

    /** A map of the buttons representing the importer to the importer */
    private Hashtable importerMap = new Hashtable();

    private JButton nextButton;
    private JButton cancelButton;
    private JButton backButton;

    /** The selected import definition */
    private ImportDefinition selectedDefinition = null;
    
    /** The main panel of dialog window.  */
    JPanel main = new JPanel(new BorderLayout());

    /** The panel that shows the list of importers */
    JPanel importersPanel;


    /** The dynamic part */
    JPanel center;
    JPanel old;


    /** Constructor that takes the owning JDBV application */
    public ImportRegistryWindow( JDBV jdbv ) throws HeadlessException
    {
        super(jdbv.MAIN_WINDOW, jdbv.PROGRAM_NAME + " Import Window", true);

        this.jdbv = jdbv;
        registry = jdbv.IMPORT_REGISTRY;
        setContentPane(main);
        initDialog();
        initListeners();
        main.add(addButtonPanel(),BorderLayout.SOUTH);
    }

    //TODO Make this pretty!!!!!!!!
    /** Creates a borderLayout JPanel containing a a title, a group of
     *  radio buttons representing the importers specified by the congin
     *  file and action buttons.  The buttons allow for cancelation or 
     *  importation (I just like saying importation)*/
    public void initDialog()
    {
        setSize( DEFAULT_WINDOW_SIZE );
        setLocationRelativeTo(jdbv.MAIN_WINDOW);

        center = new JPanel(new BorderLayout());
        center.add(new JLabel("Select Importation Method",JLabel.CENTER),
                   BorderLayout.NORTH);
	
        importersPanel = new JPanel(new GridLayout(0,1));
        java.util.List importers = jdbv.IMPORT_REGISTRY.getImporterList();
        ButtonGroup buttonGroup = new ButtonGroup();
        JRadioButton radioButton;
        ImportDefinition importDefinition;

        for(Iterator i = importers.iterator();i.hasNext();){
            importDefinition = (ImportDefinition)i.next();

            radioButton = new JRadioButton(importDefinition.getDescription());
            radioButton.setActionCommand("select");
            radioButton.addActionListener(this);

            buttonGroup.add(radioButton);
            importerMap.put(radioButton,importDefinition);
            importersPanel.add(radioButton);
        }
        center.add(importersPanel);

        nextButton = new JButton("Next");
        nextButton.setEnabled(false);
        nextButton.addActionListener(this);
        cancelButton = new JButton("Cancel");
        cancelButton.addActionListener(this);
        JPanel buttonPanel = new JPanel(new GridLayout(0,2));
        buttonPanel.add(cancelButton);
        buttonPanel.add(nextButton);

        main.add(center);
    }


    private JPanel addButtonPanel(){
        nextButton = new JButton("Next");
        nextButton.setEnabled(false);
        nextButton.addActionListener(this);

        cancelButton = new JButton("Cancel");
        cancelButton.addActionListener(this);

        backButton = new JButton("Back");
        backButton.addActionListener(this);
        backButton.setEnabled(false);

        JPanel buttonPanel = new JPanel(new GridLayout(0,4));
        buttonPanel.add(cancelButton);
        buttonPanel.add(new JLabel());
        buttonPanel.add(backButton);
        buttonPanel.add(nextButton);
        return buttonPanel;
    }

    /** Initializes additional GUI component listeners */
    private void initListeners()
    {
        addWindowListener( new WindowAdapter() {
                public void windowClosing( WindowEvent e )
                {
                }
            });
    }


    /**
     * Initiates the window-close operation, managing confirming with the user
     * if data will be lost (and should be saved). This
     * roughly translates to exiting the application. However, to handle
     * initiating exiting the application, the higher-level JDBV.handleExit()
     * method should be called.  This method should not be called directly!
     *
     * @return whether this operation completed successfully
     */
    public boolean handleClose()
    {
        // TODO more here?
        return (handleCloseDiagrams());
    }


    /**
     * Closes all the diagrams, confirming with the user if data will be lost
     *
     * @return whether this operation completed successfully
     */
    public boolean handleCloseDiagrams()
    {
        // TODO call all open diagrams handleClose()

        return (true);
    }

    public void actionPerformed(ActionEvent e)
    {
        String command = e.getActionCommand();

        if(command.equals("select")) {
            if(nextButton.isEnabled() == false)
                nextButton.setEnabled(true);
            selectedDefinition = 
                (ImportDefinition)importerMap.get(e.getSource());

        }
        else if(command.equals("Next")){
            old = center;
            main.remove(center);
            center = selectedDefinition.getGuiPanel();
            backButton.setEnabled(true);
            nextButton.setActionCommand("Import");
            main.add(center);
            pack();
            invalidate();
            validate();
            repaint();
        }
        else if(command.equals("Cancel")){
            selectedDefinition = null;
            hide();
        }
        else if(command.equals("Back")){
            main.remove(center);
            nextButton.setActionCommand("Next");
            backButton.setEnabled(false);
            center = old;
            old = null;
            main.add(center);
            setSize( DEFAULT_WINDOW_SIZE );
            invalidate();
            validate();
            repaint();
        }
        else if(command.equals("Import")) {
            String valid = selectedDefinition.checkValidity();
            if(valid == null){
                hide();
            }
            else{
                JOptionPane.showMessageDialog(this,valid,"Cannot Import!",
                                              JOptionPane.WARNING_MESSAGE);
            }
		
        }
    }


    private void resetControls()
    {
        main.remove( center );
        center = importersPanel;
        main.add( importersPanel, BorderLayout.CENTER );
        old = null;
        backButton.setEnabled( false );
        nextButton.setActionCommand("Next");
        if( selectedDefinition == null ) {
            nextButton.setEnabled( false );
        } else {
            nextButton.setEnabled( true );
        }

        setSize( DEFAULT_WINDOW_SIZE );
        invalidate();
        validate();
        repaint();
    }


    /**
     * This method is used to show the import window which will result in
     *  a call to a specific imports import() procedure.  
     * @return a schema generated by the selected importer
     */
    public Schema importSchema() throws ImportException
    {
        resetControls();
        show();
        if( selectedDefinition != null ) {
            return (selectedDefinition.importSchema());
        } else {
            return (null);
        }
    }

}

