////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.gui;

import edu.uiuc.jdbv.JDBV;
import edu.uiuc.jdbv.AutoArrangeAction;

import java.awt.*;
import javax.swing.*;

/**
 * The menu bar for the main JDBV window and the actions that can
 * be performed through the menu bar.
 *
 * @author Brian Sidharta
 * @author Ross Paul
 * @version $Revision: 1.15 $
 */
public class JDBVMenuBar extends JMenuBar
{
    /** The file menu name = "File" */
    public static final String FILE_MENU_NAME = "File";

    /** The edit menu name = "Edit" */
    public static final String EDIT_MENU_NAME = "Edit";

    /** The diagram menu name = "Diagram" */
    public static final String DIAGRAM_MENU_NAME = "Diagram";

    /** The help menu name = "Help" */
    public static final String HELP_MENU_NAME = "Help";
	
    /** The menu bar names, in order of listing */
    public static final String[] MENU_BAR_NAMES = { 
        FILE_MENU_NAME, EDIT_MENU_NAME, DIAGRAM_MENU_NAME, HELP_MENU_NAME
    };

    /** the JDBV application instance */
    private JDBV jdbv;
	
    /** Default constructor that takes the JDBV application instance */
    public JDBVMenuBar( JDBV jdbv )
    {
        this.jdbv = jdbv;
        
        initFileMenu();
        initEditMenu();
        initDiagramMenu();
        initHelpMenu();
    }

    /** Creates and adds the File JMenu to this menu bar */
    private void initFileMenu()
    {	
        JMenu menu = new JMenu( FILE_MENU_NAME );
        menu.add( jdbv.IMPORT_SCHEMA_ACTION );
        menu.add( jdbv.LOAD_DIAGRAM_ACTION );
        menu.add( jdbv.SAVE_DIAGRAM_ACTION );
        menu.add( jdbv.SAVE_AS_DIAGRAM_ACTION );
        menu.add( jdbv.CLOSE_DIAGRAM_ACTION );
        menu.addSeparator();
        menu.add( jdbv.PRINT_ACTION );
        menu.add( jdbv.PRINT_PREVIEW_ACTION );
        menu.add( jdbv.PAGE_SETUP_ACTION );
        menu.addSeparator();
        menu.add( jdbv.EXIT_ACTION );
        add( menu );
    }

    private void initEditMenu()
    {
        JMenu menu = new JMenu( EDIT_MENU_NAME );
        menu.add( jdbv.UNDO_ACTION );
        menu.add( jdbv.REDO_ACTION );
        menu.addSeparator();
        menu.add( jdbv.AUTO_ARRANGE_ACTION.getMenuItem());
        add( menu );
    }

    private void initDiagramMenu()
    {
        JMenu menu = new JMenu( DIAGRAM_MENU_NAME );
		
	menu.add( jdbv.ZOOM_NORMAL_ACTION );
	menu.add( jdbv.ZOOM_IN_ACTION );
	menu.add( jdbv.ZOOM_OUT_ACTION );

        add( menu );
    }

    private void initHelpMenu()
    {
        JMenu menu = new JMenu( HELP_MENU_NAME );
        menu.add( jdbv.HELP_ABOUT_ACTION );
        add( menu );
    }


}

