////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.gui;

import java.awt.*;
import javax.swing.*;

/**
 * The splash screen window that just displays an image and status info
 * @author Brian Sidharta
 * @version $Revision: 1.3 $
 */
public class SplashWindow extends JWindow
{
    /** 
     * The minimum amount of time that the splash screen is displayed
     * in milliseconds = 2500
     */
    private static final int MIN_SHOW_TIME = 2500;



    /** The time it was last shown, in milliseconds since epoch */
    private long showTime = 0;

    /** The JLabel that displays status text */
    private JLabel statusLabel;



    /** Constructor that takes the name of the splash image file */
    public SplashWindow( String splashFilename )
    {
        Icon splashIcon = 
	    new ImageIcon( ClassLoader.getSystemResource( splashFilename ));
        initComponents( splashIcon );
        pack();

        moveToScreenCenter();

    }


    /** Initializes swing components */
    private void initComponents( Icon splashIcon )
    {
        JPanel cPane = (JPanel)getContentPane();
        cPane.setLayout( new BorderLayout());
        cPane.setBorder( BorderFactory.createLineBorder( Color.black ));

        JLabel splashLabel = new JLabel( splashIcon );
        cPane.add( splashLabel, BorderLayout.CENTER );

        statusLabel = new JLabel( "Starting..." );
        statusLabel.setBorder( BorderFactory.createLoweredBevelBorder());
        cPane.add( statusLabel, BorderLayout.SOUTH );
    }

    /** Center the window in the user's screen */
    private void moveToScreenCenter()
    {
        Toolkit tk = Toolkit.getDefaultToolkit();
        Dimension screenDim = tk.getScreenSize();
        Dimension thisDim = getSize();
        int x = (screenDim.width - thisDim.width ) / 2;
        int y = (screenDim.height - thisDim.height ) / 2;

        setLocation( x, y );
    }



    /** Sets the status text displayed in the splash screen */
    public void setStatus( String status )
    {
        statusLabel.setText( status );
    }


    /**
     * Sets whether the window is visible or not. Overridden so the splash
     * screen can be shown for a set-minimum amount of time, so user can see
     * it.
     */
    public void setVisible( boolean show )
    {
        if( show ) {
            super.setVisible( true );
            showTime = System.currentTimeMillis();
        } else {
            long currTime = System.currentTimeMillis();
            long diffTime = MIN_SHOW_TIME + showTime - currTime;
            if( diffTime > 0 ) {
                try{
                    Thread.sleep( diffTime );
                    showTime = 0;
                    setVisible( false ); // Called on SplashWindow
                } catch( InterruptedException intrE ) {
                    intrE.printStackTrace();
                }
            } else {
                super.setVisible( false );
            }
        }
    }


}

