////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

import net.javaprog.ui.*;

import edu.uiuc.jdbv.JDBV;
import edu.uiuc.jdbv.schema.*;
import edu.uiuc.jdbv.diagram.Diagram;


/**
 * The TableListModel wraps a Schema so the table list can be displayed in
 * a swing list component
 *
 * @author Brian Sidharta
 * @version $Revision: 1.5 $
 */
public class TableListModel extends AbstractCheckBoxListModel
{
    /** The schema that we're wrapping */
    private Schema schema = null;

    /** The Diagram that we're wrapping */
    private Diagram diagram = null;

    /** The table list */
    private Table[] tables = null;


    /**
     * Retrieves the element at a specified index. For ListModel interface.
     *  
     * @param index the 0-based index of the item to retrieve
     * @return Object the data at the specified index
     */
    public Object getElementAt( int index )
    {
        if( schema != null ) {
            return (tables[index]);
        } else {
            return (null);
        }
    }



    /**
     * Returns the length of the list. For ListModel interface.
     */
    public int getSize()
    {
        if( schema != null ) {
            return (tables.length);
        } else {
            return (0);
        }
    }


	/**
	 * Returns whether the element at the specified position is
	 * checked.
	 *
	 * @param index the position of the element
	 * @return whether the element at <code>index</code> is checked
     * @see net/javaprog/ui/CheckBoxListModel
	 */
	public boolean isElementChecked( int index )
    {
        if( schema == null || diagram == null ) {
            return (false);
        } else {
            return (diagram.containsTable( tables[index] ));
        }
    }


	/**
	 * Checks or unchecks the element at the given position.
	 *
	 * @param index the position of the element
	 * @param checked whether the element at <code>index</code> should
     *        be checked or not
     * @see net/javaprog/ui/CheckBoxListModel
	 */
	public void setElementChecked(int index,boolean checked)
    {
        Action action;
        ActionEvent ae;

        if( checked ) {
            ae = new ActionEvent( this, 0, "Add Table" );
            action = JDBV.getInstance().ADD_TABLE_ACTION;
        } else {
            ae = new ActionEvent( this, 0, "Remove Table" );
            action = JDBV.getInstance().REMOVE_TABLE_ACTION;
        }
        action.actionPerformed( ae );
    }


	/**
	 * Returns the number of checked elements in this model.
	 *
	 * @return the number of checked elements
     * @see net/javaprog/ui/CheckBoxListModel
	 */
	public int getCheckedElementsCount()
    {
        if( diagram == null ) {
            return (0);
        }
        return (diagram.getNumTables());

    }



    /**
     * Sets the schema that this table list is displaying
     */
    public void setSchema( Schema schema )
    {
        fireIntervalRemoved( this, 0, getSize());
        this.schema = schema;
        if( schema != null ) {
            this.tables = schema.getTables();
        }
        fireIntervalAdded( this, 0, getSize());
    }


    /**
     * Returns the schema that the table list is displaying
     */
    public Schema getSchema()
    {
        return (schema);
    }


    /**
     * Sets the diagram that this model is displaying
     */
    public void setDiagram( Diagram diagram )
    {
        if( diagram == null ) {
            // Null diagram means a null schema
            setSchema( null );
        } else {
            setSchema( diagram.getSchema());
        }

        this.diagram = diagram;
        fireContentsChanged( this, 0, getSize());
    }

    /**
     * Returns the diagram that this model is displaying
     */
    public Diagram getDiagram()
    {
        return (diagram);
    }

}

