////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
// ImportDefinition.java
package edu.uiuc.jdbv.imports;

import javax.swing.JPanel;
import edu.uiuc.jdbv.schema.*;
/*<Imports>*/
/*</Imports>*/

/**
 * The Abstract class that provides a template for all Data importeters.
 *
 * @author Abhay Sathe
 * @author Ross Paul
 * @version $Revision: 1.8 $
 */
public abstract class ImportDefinition
{
    // Public constructors
    
    // Public methods
    /**
     * Provide a brief textual description of what the importer will do.
     * This is used when when the users is selecting which importer to use.
     * @return String Description- One line, 30 max characters including spaces
     */
    public abstract String getDescription ()  ;

    /**
     * Import a schema from data source.  
     */
    public abstract Schema importSchema() throws ImportException ;


    /** This class will be called to bring up a modal dialog
     *  where the user shall specify importer specific parameters
     *  these paramaters should be saved in the specific importer */
    public abstract JPanel getGuiPanel();

    /** This method is called immediately prior to importSchema().  The
     *  intention is for the importer to provide feedback on the state of the
     *  parameters set by the user (i.e. are all of the needed params set).
     *  The return is used to display an error message if the params are not 
     *  correct.  Return null if everything checks out.
     *  @return null if everything is fine, otherwise a message detailing the
     *  problem. */
    public abstract String checkValidity();
}
// end of ImportDefinition.jav
