////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.imports.oracle;

import edu.uiuc.jdbv.gui.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;

/**
 * Gui which populates DBImportDefinition with the correct database
 * @author Uday Kale
 * @author Brian Sidharta
 * @version $Revision: 1.8 $
 */
public class DBGuiPanel extends JPanel
	implements FocusListener
{

    /** The logger to be used for the file */
    private static final org.apache.log4j.Logger LOG = 
        org.apache.log4j.Logger.
        getLogger("jdbv.imports.oracle.DBGuiPanel");


    private DBImportDefinition dbimport;
    private JTextField hostField;
    private JTextField portField;
    private JTextField instField;
    private JTextField userField;
    private JPasswordField passwdField;

    /** Constructor needs to take in the importer it is tied to */
    public DBGuiPanel(DBImportDefinition dbDef) {

	super(new BorderLayout());
	dbimport = dbDef;

	// Set the default database type
	dbimport.setDatabase("Oracle");

	add(new JLabel
	    ("Select a database to import from and give connection details", 
		JLabel.CENTER), BorderLayout.NORTH);

	JPanel centerPanel = new JPanel();
	centerPanel.setLayout(new BoxLayout(centerPanel,BoxLayout.Y_AXIS));
	centerPanel.add(addDBTypeOptions());
	centerPanel.add(Box.createVerticalStrut(5));

	JPanel connStrPanel = new JPanel();
	connStrPanel.setLayout(new BoxLayout(connStrPanel,BoxLayout.Y_AXIS));
	connStrPanel.add(addConnStrPanel());

	centerPanel.add(connStrPanel);
	add(centerPanel);

    }

    private JPanel addConnStrPanel() {

	JPanel connPanel = new JPanel(new GridLayout(5,2));
	hostField = new JTextField(30);
	portField = new JTextField(10);
	instField = new JTextField(20);
	userField = new JTextField(20);
	passwdField = new JPasswordField(20);

	connPanel.add(new JLabel("Hostname/ IP Address"));
	connPanel.add(hostField);
	connPanel.add(new JLabel("Port no"));
	connPanel.add(portField);
	connPanel.add(new JLabel("Instance Name"));
	connPanel.add(instField);
	connPanel.add(new JLabel("User name"));
	connPanel.add(userField);
	connPanel.add(new JLabel("Password"));
	connPanel.add(passwdField);

	connPanel.setBorder
		(BorderFactory.createTitledBorder("Connection Details"));

	hostField.addFocusListener(this);
	portField.addFocusListener(this);
	instField.addFocusListener(this);
	userField.addFocusListener(this);
	passwdField.addFocusListener(this);

	return connPanel;
    }

    private JPanel addDBTypeOptions() {

	JPanel DBTypesPanel = new JPanel(new GridLayout(0,1));
	ButtonGroup buttonGroup = new ButtonGroup();
	JRadioButton dbButton;

	dbButton = new JRadioButton("Oracle Database",true);
	buttonGroup.add(dbButton);
	DBTypesPanel.add(dbButton);

	dbButton = new JRadioButton("Informix Database");
	dbButton.setEnabled(false);
	buttonGroup.add(dbButton);
	DBTypesPanel.add(dbButton);

	DBTypesPanel.setBorder
		(BorderFactory.createTitledBorder("Database Type"));
	return DBTypesPanel;
    }

    public void focusGained(FocusEvent e){
    }

    public void focusLost(FocusEvent e){

	String host = hostField.getText();
	String port = portField.getText();
	String inst = instField.getText();
	String user = userField.getText();
	String pass = new String(passwdField.getPassword());

	if ((host.equals("")) || (port.equals("")) || (inst.equals("")) || 
	    (user.equals("")))
		return;

	String connstr = new String(host+":"+port+":"+inst);
	LOG.debug("Connection String is : "+connstr);
	LOG.debug("User/Password : "+user+pass);
	dbimport.setConnString(connstr, user, pass);
    }
}
