////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
package edu.uiuc.jdbv.imports.sql;

import edu.uiuc.jdbv.gui.*;
import edu.uiuc.jdbv.util.SuffixFileFilter;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;

/**
 * Gui which populates SqlImportDefinition with the correct file to parse
 * @author Ross Paul
 * @author Brian Sidharta
 * @version $Revision: 1.9 $
 */
public class SqlGuiPanel extends JPanel 
    implements FocusListener, ActionListener
{
    /** Description for SQL Files */
    public static final String SQL_FILE_DESC = "SQL Script Files";

    /** Extensions for SQL filenames */
    public static final String[] SQL_FILE_EXTENSIONS = {"sql"};


    private static final JFileChooser fileChooser;


    private SqlImportDefinition sqlImport;
    private JTextField fileField = new JTextField(15);
    private JButton browseButton = new JButton("Browse...");


    static {
        SuffixFileFilter fileFilter = 
            new SuffixFileFilter( SQL_FILE_DESC, SQL_FILE_EXTENSIONS );

        fileChooser = new JFileChooser( "." );
        fileChooser.addChoosableFileFilter( fileFilter );

    }
    

    /** Constructor needs to take in the importer it is tied to */
    public SqlGuiPanel(SqlImportDefinition sqlDef){
	super(new BorderLayout());
	sqlImport = sqlDef;

	add(new JLabel("Select a File to Import",JLabel.CENTER), 
	    BorderLayout.NORTH);

	JPanel centerPanel = new JPanel();
	centerPanel.setLayout(new BoxLayout(centerPanel,BoxLayout.Y_AXIS));
	centerPanel.add(addFileTypeOptions());
	centerPanel.add(Box.createVerticalStrut(5));

	JPanel fileInfoPanel = new JPanel();
	fileInfoPanel.add(new JLabel("File Name: "));
	fileInfoPanel.add(fileField);
	fileInfoPanel.add(browseButton);
	
	centerPanel.add(fileInfoPanel);
	add(centerPanel);

	browseButton.addActionListener(this);
	fileField.addFocusListener(this);
    }

    //TODO actually make this do something...currently takes up white space
    /** Adds the list of sql file Types */
    private JPanel addFileTypeOptions(){
	JPanel sqlTypesPanel = new JPanel(new GridLayout(0,1));
	ButtonGroup buttonGroup = new ButtonGroup();
	JRadioButton hackButton;
	
	hackButton = new JRadioButton("SQL87");
	hackButton.setEnabled(false);
	buttonGroup.add(hackButton);
	sqlTypesPanel.add(hackButton);

	hackButton = new JRadioButton("SQL92",true);
	buttonGroup.add(hackButton);
	sqlTypesPanel.add(hackButton);

	hackButton = new JRadioButton("MS SQL Server");
	hackButton.setEnabled(false);
	buttonGroup.add(hackButton);
	sqlTypesPanel.add(hackButton);

	hackButton = new JRadioButton("Oracle SQL");
	hackButton.setEnabled(false);
	buttonGroup.add(hackButton);
	sqlTypesPanel.add(hackButton);

	sqlTypesPanel.setBorder(BorderFactory.createTitledBorder("SQL Type"));

	return sqlTypesPanel;
    }

    /** Used to bring up the file chooser */
    public void actionPerformed(ActionEvent e){
	String command = e.getActionCommand();

	if(command.equals("Browse...")){
	    int returnVal = fileChooser.showOpenDialog(this);
	    if (returnVal == JFileChooser.APPROVE_OPTION) {
		fileField.setText(fileChooser.getSelectedFile().getPath());
		sqlImport.setFile(fileChooser.getSelectedFile());
	    }
	}
    }

    public void focusGained(FocusEvent e){
    }

    public void focusLost(FocusEvent e){
	String fileName = fileField.getText();
	System.out.println(fileName);
	if(fileField != null){
	    try{
		sqlImport.setFile(new File(fileName));
	    }catch(Exception ex){ex.printStackTrace();}
	}
    }




}
