////////////////////////////////////////////////////////////////////////////
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////
// SqlImport.java
package edu.uiuc.jdbv.imports.sql;

/**
 * The importSchema method parses a sql file and returns a schema object
 * 
 *
 * @author Brian Schoudel
 * @version $Revision: 1.18 $
 */

/*<Imports>*/
import java.io.*;
import java.util.*;
import edu.uiuc.jdbv.imports.*;
import edu.uiuc.jdbv.schema.*;
import javax.swing.JPanel;
import org.apache.torque.engine.database.transform.SQLToAppData;  //SQL parser class
import org.apache.torque.engine.database.model.AppData;  //SQL parsed class
import org.apache.torque.engine.database.model.Table;  //Table class
import org.apache.torque.engine.database.model.Column;  //Column class
import org.apache.torque.engine.database.model.ForeignKey;  //Foreign Key class
import org.apache.torque.engine.sql.ParseException; //Parser Exception
/*</Imports>*/

/**
 * 
 */
public class SqlImportDefinition extends ImportDefinition
{
    private BufferedReader SqlRdr;

    private File file;
    

    // Public constructors
    public SqlImportDefinition(){
    }
    
    public String checkValidity(){
	if(file == null)
	    return "Please Select a Valid File";
	else if(file.exists() == false)
	    return "File '" + file.getName() + "' cannot be found.";
	else
	    return null;
    }
	

    /**
     *  Description describing the type of import
     */
    public String getDescription ()   {
        return "Import From SQL File" ;
    }

    /**
     *  Begins the sql import process
     */
   
    /** Import the schema from a sql file
     *  @return the schema that was imported  

        This handles multiple tables but not keys yet   **/

    public JPanel getGuiPanel(){
        file = null;
	return new SqlGuiPanel(this);
    }

    public Schema importSchema() throws ImportException
    {
	Schema sqlSchema = new Schema("sqlSchema");

	System.out.println("The file path is" + file.getPath() );

	SQLToAppData sqlParse = new SQLToAppData(file.getPath() );

        try
        {
	  //parse the import sql file
          AppData ad = sqlParse.execute();

	  //retrieve the tables
          org.apache.torque.engine.database.model.Table[] tablesArray = ad.getDatabase().getTables();

          TorqueToDbviz createSchema = new TorqueToDbviz(tablesArray);

	  sqlSchema = createSchema.convert();


	}
	//catch import exceptions
        catch (IOException ioe) 
        { //Open catch
          System.out.println("An importer exception was thrown: " + ioe);
        } // Close catch
        catch (ParseException pe) 
        { //Open catch
          System.out.println("A parse exception was thrown: " + pe);
        } // Close catch    
	    
        
        return sqlSchema;
    }   //end function importSchema


    public void setFile(File file){
	this.file = file;
    }


  /**  This is a main method to test the ImportSchema method  **/

  public static void main( String args[] )
  {
    SqlImportDefinition ie = new SqlImportDefinition();
    Schema schema = new Schema("Test Schema");
    try {
	schema = ie.importSchema();
    }catch(Exception e){e.printStackTrace();}
    System.out.println("The Real Schema is " + schema.getName());
    System.out.println("The Table is " + schema.getTable("Student_Course").getName());  
  }

    
}
// end of SqlImport.java
